@@ -1059,7 +1059,7 @@ use Log::Handler::Pattern;
 use UNIVERSAL;
 use base qw(Log::Handler::Levels);
 
-our $VERSION = "0.71";
+our $VERSION = "0.72";
 our $ERRSTR  = "";
 
 # $TRACE and $CALLER_LEVEL are both used as global
@@ -1390,6 +1390,11 @@ sub set_pattern {
         Carp::croak "invalid/missing name for pattern '$pattern'";
     }
 
+    if (ref($code) ne "CODE") {
+        my $str = $code;
+        $code = sub { $str };
+    }
+
     # Structure:
     #   $self->{pattern}->{"%X"}->{name} = "name-of-x";
     #   $self->{pattern}->{"%X"}->{code} = "value-of-x";
